from nwon_baseline.typings import BoundingBoxCoordinates as BoundingBoxCoordinates, BoundingBoxTuple as BoundingBoxTuple

def bounding_box_coordinates_from_tuple(box: BoundingBoxTuple): ...
def bounding_box_tuple_from_coordinates(box: BoundingBoxCoordinates) -> BoundingBoxTuple: ...
