from typing import BinaryIO, Optional, TextIO

def file_extension_from_url(image_url: str) -> str: ...
def file_extension_from_path(path: str) -> str: ...
def get_file_object(file_path: str) -> Optional[TextIO]: ...
def get_file_as_binary(file_path: str) -> Optional[BinaryIO]: ...
def read_file_as_binary(file_path: str) -> Optional[bytes]: ...
def read_file_content(file_path: str) -> Optional[str]: ...
def handle_uploaded_file(file, destination_path) -> str: ...
